Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2093)

Unified Diff: chrome/browser/android/download/download_controller_base.h

Issue 2014803002: Move DownloadControllerAndroid from content/ to chrome/ (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: reverted ResourceDispatcherHost Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/android/download/download_controller_base.h
diff --git a/content/public/browser/android/download_controller_android.h b/chrome/browser/android/download/download_controller_base.h
similarity index 64%
rename from content/public/browser/android/download_controller_android.h
rename to chrome/browser/android/download/download_controller_base.h
index 7eda0e9774b3202944c1e47469fbde90f2ff309b..b5d48ec335364f6dca5748085e08a4773e7860bd 100644
--- a/content/public/browser/android/download_controller_android.h
+++ b/chrome/browser/android/download/download_controller_base.h
@@ -2,46 +2,52 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_PUBLIC_BROWSER_ANDROID_DOWNLOAD_CONTROLLER_ANDROID_H_
-#define CONTENT_PUBLIC_BROWSER_ANDROID_DOWNLOAD_CONTROLLER_ANDROID_H_
+#ifndef CHROME_BROWSER_ANDROID_DOWNLOAD_DOWNLOAD_CONTROLLER_BASE_H_
+#define CHROME_BROWSER_ANDROID_DOWNLOAD_DOWNLOAD_CONTROLLER_BASE_H_
#include "base/callback.h"
-#include "content/common/content_export.h"
#include "content/public/browser/download_item.h"
#include "content/public/common/context_menu_params.h"
+namespace net {
+class URLRequest;
+}
+
namespace content {
class DownloadItem;
class WebContents;
+}
// Interface to request GET downloads and send notifications for POST
// downloads.
-class CONTENT_EXPORT DownloadControllerAndroid : public DownloadItem::Observer {
+class DownloadControllerBase : public content::DownloadItem::Observer {
public:
- // Returns the singleton instance of the DownloadControllerAndroid.
- static DownloadControllerAndroid* Get();
+ // Returns the singleton instance of the DownloadControllerBase.
+ static DownloadControllerBase* Get();
- // Called to set the DownloadControllerAndroid instance.
- static void SetDownloadControllerAndroid(
- DownloadControllerAndroid* download_controller);
+ // Called to set the DownloadControllerBase instance.
+ static void SetDownloadControllerBase(
+ DownloadControllerBase* download_controller);
// Starts a new download request with Android. Should be called on the
// UI thread.
virtual void CreateGETDownload(int render_process_id, int render_view_id,
- int request_id, bool must_download) = 0;
+ const net::URLRequest* request,
+ bool must_download) = 0;
// Should be called when a download is started. It can be either a GET
// request with authentication or a POST request. Notifies the embedding
// app about the download. Should be called on the UI thread.
- virtual void OnDownloadStarted(DownloadItem* download_item) = 0;
+ virtual void OnDownloadStarted(content::DownloadItem* download_item) = 0;
// Called when a download is initiated by context menu.
virtual void StartContextMenuDownload(
- const ContextMenuParams& params, WebContents* web_contents,
+ const content::ContextMenuParams& params,
+ content::WebContents* web_contents,
bool is_link, const std::string& extra_headers) = 0;
// Called when a dangerous download item is verified or rejected.
- virtual void DangerousDownloadValidated(WebContents* web_contents,
+ virtual void DangerousDownloadValidated(content::WebContents* web_contents,
const std::string& download_guid,
bool accept) = 0;
@@ -52,21 +58,19 @@ class CONTENT_EXPORT DownloadControllerAndroid : public DownloadItem::Observer {
// Called to prompt the user for file access permission. When finished,
// |callback| will be executed.
virtual void AcquireFileAccessPermission(
- WebContents* web_contents,
+ content::WebContents* web_contents,
const AcquireFileAccessPermissionCallback& callback) = 0;
// Called by unit test to approve or disapprove file access request.
- virtual void SetApproveFileAccessRequestForTesting(bool approve) {};
+ virtual void SetApproveFileAccessRequestForTesting(bool approve) {}
// Called to set the default download file name if it cannot be resolved
// from url and content disposition
virtual void SetDefaultDownloadFileName(const std::string& file_name) {}
protected:
- ~DownloadControllerAndroid() override {};
- static DownloadControllerAndroid* download_controller_;
+ ~DownloadControllerBase() override {}
+ static DownloadControllerBase* download_controller_;
};
-} // namespace content
-
-#endif // CONTENT_PUBLIC_BROWSER_ANDROID_DOWNLOAD_CONTROLLER_ANDROID_H_
+#endif // CHROME_BROWSER_ANDROID_DOWNLOAD_DOWNLOAD_CONTROLLER_BASE_H_

Powered by Google App Engine
This is Rietveld 408576698